@@ -1,4 +1,4 @@
 """pysequila."""
 from pysequila.sequila import SequilaSession
 
-__all__ = ['SequilaSession']
+__all__ = ["SequilaSession"]
